# Symbol

Show a simple geometric symbol (square, triangle, circle) in a specified color. Can optionally collect keyboard responses.

## When To Use

- Minimal, highly controlled visual tokens.
- Cues or placeholders with low visual complexity.

## Example

Show a set of colored symbols.

![symbols](../../img/stimuli/symbols.png)
